@@ -7,7 +7,9 @@
 # Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ...workbook import Workbook
+from xlsxwriter.color import Color
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
 
 
@@ -25,7 +27,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         workbook = Workbook(self.got_filename)
 
-        workbook.custom_colors = ["FF0000FF"]
+        workbook.custom_colors = [Color("#0000FF")]
 
         worksheet = workbook.add_worksheet()
         format1 = workbook.add_format({"hyperlink": 1})
@@ -45,7 +47,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         workbook = Workbook(self.got_filename)
 
-        workbook.custom_colors = ["FF0000FF"]
+        workbook.custom_colors = [Color("#0000FF")]
 
         worksheet = workbook.add_worksheet()
         format2 = workbook.add_format({"font_color": "red", "underline": 1})
