@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,19 +19,18 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('macro03.xlsm')
+        self.set_filename("macro03.xlsm")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
 
         workbook = Workbook(self.got_filename)
 
-        worksheet = workbook.add_worksheet('Foo')
+        worksheet = workbook.add_worksheet("Foo")
 
-        workbook.add_vba_project(self.vba_dir + 'vbaProject04.bin')
+        workbook.add_vba_project(self.vba_dir + "vbaProject04.bin")
 
-        worksheet.write('A1', 123)
+        worksheet.write("A1", 123)
 
         workbook.close()
 
