@@ -10,7 +10,7 @@
 import datetime
 import unittest
 
-from ...worksheet import Worksheet
+from xlsxwriter.worksheet import Worksheet
 
 
 class TestConvertDateTime(unittest.TestCase):
