@@ -3,13 +3,16 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
+from xlsxwriter.worksheet import Worksheet
+
 from ..helperfunctions import _xml_to_list
-from ...worksheet import Worksheet
 
 
 class TestAssembleWorksheet(unittest.TestCase):
@@ -17,6 +20,7 @@ class TestAssembleWorksheet(unittest.TestCase):
     Test assembling a complete Worksheet file.
 
     """
+
     def test_assemble_xml_file(self):
         """Test writing a worksheet with no cell data."""
         self.maxDiff = None
@@ -25,25 +29,25 @@ class TestAssembleWorksheet(unittest.TestCase):
         worksheet = Worksheet()
         worksheet._set_filehandle(fh)
         worksheet.select()
-        worksheet.name = 'Sheet1'
+        worksheet.name = "Sheet1"
         worksheet.excel_version = 2010
 
         data = [-2, 2, 3, -1, 0]
-        worksheet.write_row('A1', data)
+        worksheet.write_row("A1", data)
 
         # Set up sparklines.
 
         # Test all the styles.
         for i in range(36):
             row = i + 1
-            sparkrange = 'Sheet1!A%d:E%d' % (row, row)
+            spark_range = f"Sheet1!A{row}:E{row}"
             worksheet.write_row(i, 0, data)
-            worksheet.add_sparkline(i, 5, {'range': sparkrange,
-                                           'style': row})
+            worksheet.add_sparkline(i, 5, {"range": spark_range, "style": row})
 
         worksheet._assemble_xml_file()
 
-        exp = _xml_to_list("""
+        exp = _xml_to_list(
+            """
                 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
                 <worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac" mc:Ignorable="x14ac">
                   <dimension ref="A1:E36"/>
@@ -1249,8 +1253,9 @@ class TestAssembleWorksheet(unittest.TestCase):
                     </ext>
                   </extLst>
                 </worksheet>
-                """)
+                """
+        )
 
         got = _xml_to_list(fh.getvalue())
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
